@@ -16,7 +16,7 @@ from flask_ligand.schemas import OpenApiClientDownloadRespSchema, OpenApiClientD
 # ======================================================================================================================
 # Type Checking
 # ======================================================================================================================
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from typing import Mapping, Any
 
 # ======================================================================================================================
